@@ -4,7 +4,7 @@ import logging
 import os
 import sys
 from collections import defaultdict, OrderedDict
-from datetime import date
+from datetime import date, datetime
 from typing import DefaultDict, Any
 
 from caseconverter import kebabcase
@@ -137,12 +137,19 @@ def preservation_status(result) -> (dict, str):
     # not in sampling framework (yet)
     no = None
 
+    year = None
+    # "published": {"date-parts": [[2005, 12, 30]]}}}
+
+    if "published" in result:
+        year = result["published"]["date-parts"][0][0]
+
     return show_preservation(
         container_title=container_title,
         issn=issn,
         volume=volume,
         no=no,
         doi=result,
+        year=year,
     )
 
 
@@ -241,7 +248,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                 else None
             )
 
-            if year_published and year_published != date.today().year:
+            if year_published and str(year_published) != str(date.today().year):
                 has_preservation = False
                 archive_count = 0
 
@@ -332,6 +339,12 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     two_archives += 1
                 elif archive_count > 2:
                     three_archives += 1
+            else:
+                overall_status["excluded-current-year"] += 1
+                if verbose:
+                    logging.info(
+                        f"{result['DOI']} is excluded as is too recent"
+                    )
         else:
             # this is an excluded sample item
             if "type" in result and result["type"] != "journal-article":
@@ -620,36 +633,49 @@ def member_report(member_id):
         sample = json.loads(sample)["data-point"]
 
         if "type" in sample and sample["type"] == "journal-article":
-            # print(f"Appending {sample['DOI']}")
+            year = None
 
-            md5_doi = hashlib.md5(sample["DOI"].lower().encode()).hexdigest()
+            if "published" in sample:
+                year = sample["published"]["date-parts"][0][0]
 
-            try:
-                annotation = get_annotation(
-                    s3client=s3client,
-                    member_id=member_id,
-                    annotation_name="preservation.json",
-                    annotations_bucket=ANNOTATION_BUCKET,
-                    annotations_path=ANNOTATION_PATH,
-                    path=f"works/{md5_doi}",
-                    use_member_id=False,
-                )
+            if sample["DOI"] == "10.16995/glossa.8784":
+                print("FOUND ARTICLE")
+                print(str(year))
+                print(str(datetime.now().year))
+                print(str(year) != str(datetime.now().year))
+                print(sample)
 
-                preserved = any(
-                    v.startswith("preserved")
-                    for v in annotation.values()
-                    if isinstance(v, str)
-                )
+            if str(year) != str(datetime.now().year):
+                md5_doi = hashlib.md5(
+                    sample["DOI"].lower().encode()
+                ).hexdigest()
 
-                if not preserved:
-                    unpreserved_samples.append(annotation)
+                try:
+                    annotation = get_annotation(
+                        s3client=s3client,
+                        member_id=member_id,
+                        annotation_name="preservation.json",
+                        annotations_bucket=ANNOTATION_BUCKET,
+                        annotations_path=ANNOTATION_PATH,
+                        path=f"works/{md5_doi}",
+                        use_member_id=False,
+                    )
 
-                overall_samples.append(annotation)
+                    preserved = any(
+                        v.startswith("preserved")
+                        for v in annotation.values()
+                        if isinstance(v, str)
+                    )
 
-            except Exception as e:
-                ...
-                # print(e)
-                # print(f"This DOI was excluded: {sample['DOI']}")
+                    if not preserved:
+                        unpreserved_samples.append(annotation)
+
+                    overall_samples.append(annotation)
+
+                except Exception as e:
+                    ...
+                    # print(e)
+                    # print(f"This DOI was excluded: {sample['DOI']}")
 
     key = f"{REPORT_PATH}/members/{member_id}/preservation-report.json"
     unpreserved_key = f"{REPORT_PATH}/members/{member_id}/unpreserved.json"
@@ -659,10 +685,15 @@ def member_report(member_id):
         json_obj=unpreserved_samples,
         bucket=REPORT_BUCKET,
         path=unpreserved_key,
+        verbose=True,
     )
 
     push_json_to_s3(
-        s3=s3, json_obj=overall_samples, bucket=REPORT_BUCKET, path=key
+        s3=s3,
+        json_obj=overall_samples,
+        bucket=REPORT_BUCKET,
+        path=key,
+        verbose=True,
     )
 
 
